==> dante_corpora-1.0.5.tar.gz: dante_corpora-1.0.5/README.md <==
<a name="readme-top"></a>

<div align="center">

[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]

</div>

<!-- PROJECT LOGO -->
<br />
<div align="center">
  <a href="https://github.com/DANTE-POeTiSA/dante-corpora">
    <img src="images\dante.png" alt="Logo"  height="100" style="border-radius:50%">
  </a>

<h3 align="center">DANTE Corpora</h3>

  <p align="center">
    Pacote Python contendo os corpora do projeto DANTE do POeTiSA
    <br />
    <br />
    <a href="https://github.com/DANTE-POeTiSA/dante-corpora/issues">Report Bug</a>
    ·
    <a href="https://github.com/DANTE-POeTiSA/dante-corpora/issues">Request Feature</a>
  </p>
</div>

<br />

---

...

## Git Clone

Para obter uma cópia local deste repositório, utilize o seguinte comando:

```
git clone https://github.com/DANTE-POeTiSA/dante-corpora.git
```

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Instalação



```
pip install dante-corpora
```

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Conjunto de Dados

...


 
<p align="right">(<a href="#readme-top">back to top</a>)</p>


## Documentos importantes

...

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Contribuição

Contribuições são bem-vindas! Sinta-se à vontade para propor melhorias, relatar problemas ou abrir pull requests.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Licença

Este projeto é licenciado sob a [Licença MIT](LICENSE).

<p align="right">(<a href="#readme-top">back to top</a>)</p>

[contributors-shield]: https://img.shields.io/github/contributors/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[contributors-url]: https://github.com/DANTE-POeTiSA/dante-corpora/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[forks-url]: https://github.com/DANTE-POeTiSA/dante-corpora/network/members
[stars-shield]: https://img.shields.io/github/stars/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[stars-url]: https://github.com/DANTE-POeTiSA/dante-corpora/stargazers
[issues-shield]: https://img.shields.io/github/issues/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[issues-url]: https://github.com/DANTE-POeTiSA/dante-corpora/issues
[license-shield]: https://img.shields.io/github/license/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[license-url]: https://github.com/DANTE-POeTiSA/dante-corpora/blob/master/LICENSE.txt

==> dante_corpora-1.0.7.tar.gz: dante_corpora-1.0.7/README.md <==
<a name="readme-top"></a>

<div align="center">
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
</div>

<br />
<div align="center">
  <a href="https://github.com/DANTE-POeTiSA/dante-corpora">
    <img src="https://github.com/DANTE-POeTiSA/dante-corpora/blob/main/images/dante.png?raw=true" alt="Logo"  height="100" style="border-radius:50%">
  </a>

<h3 align="center">DANTE Corpora</h3>

  <p align="center">
    Pacote Python contendo os corpora do projeto DANTE do POeTiSA
    <br />
    <br />
    <a href="https://github.com/DANTE-POeTiSA/dante-corpora/issues">Report Bug</a>
    -
    <a href="https://github.com/DANTE-POeTiSA/dante-corpora/issues">Request Feature</a>
  </p>
</div>

<br />

---

...

## Git Clone

Para obter uma copia local deste repositorio, utilize o seguinte comando:

```
git clone https://github.com/DANTE-POeTiSA/dante-corpora.git
```

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Instalacao



```
pip install dante-corpora
```

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Conjunto de Dados

...


 
<p align="right">(<a href="#readme-top">back to top</a>)</p>


## Documentos importantes

...

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Contribuição

Contribuicoes sao bem-vindas! Sinta-se a vontade para propor melhorias, relatar problemas ou abrir pull requests.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

## Licença

Este projeto e licenciado sob a [Licença MIT](LICENSE).

<p align="right">(<a href="#readme-top">back to top</a>)</p>

[contributors-shield]: https://img.shields.io/github/contributors/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[contributors-url]: https://github.com/DANTE-POeTiSA/dante-corpora/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[forks-url]: https://github.com/DANTE-POeTiSA/dante-corpora/network/members
[stars-shield]: https://img.shields.io/github/stars/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[stars-url]: https://github.com/DANTE-POeTiSA/dante-corpora/stargazers
[issues-shield]: https://img.shields.io/github/issues/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[issues-url]: https://github.com/DANTE-POeTiSA/dante-corpora/issues
[license-shield]: https://img.shields.io/github/license/DANTE-POeTiSA/dante-corpora.svg?style=for-the-badge
[license-url]: https://github.com/DANTE-POeTiSA/dante-corpora/blob/master/LICENSE.txt
